@@ -1,16 +1,16 @@
 import sys
 
-from graphql.execution.base import ResolveInfo
+from graphene import ResolveInfo
 from rx import Observable
 
 import dagster._check as check
-from dagster.core.events import DagsterEventType, EngineEventData
-from dagster.core.instance import DagsterInstance
-from dagster.core.storage.compute_log_manager import ComputeIOType
-from dagster.core.storage.event_log.base import EventLogCursor
-from dagster.core.storage.pipeline_run import PipelineRunStatus, RunsFilter
-from dagster.serdes import serialize_dagster_namedtuple
-from dagster.utils.error import serializable_error_info_from_exc_info
+from dagster._core.events import DagsterEventType, EngineEventData
+from dagster._core.instance import DagsterInstance
+from dagster._core.storage.compute_log_manager import ComputeIOType
+from dagster._core.storage.event_log.base import EventLogCursor
+from dagster._core.storage.pipeline_run import PipelineRunStatus, RunsFilter
+from dagster._serdes import serialize_dagster_namedtuple
+from dagster._utils.error import serializable_error_info_from_exc_info
 
 from ..external import ExternalPipeline, ensure_valid_config, get_external_pipeline_or_raise
 from ..fetch_runs import is_config_valid
