@@ -1,13 +1,15 @@
 import pendulum
 
-from dagster import check
-from dagster.core.execution.backfill import (
+import dagster._check as check
+from dagster._core.errors import DagsterError
+from dagster._core.events import AssetKey
+from dagster._core.execution.backfill import (
     BulkActionStatus,
     PartitionBackfill,
     submit_backfill_runs,
 )
-from dagster.core.host_representation import RepositorySelector
-from dagster.core.utils import make_new_backfill_id
+from dagster._core.host_representation import RepositorySelector
+from dagster._core.utils import make_new_backfill_id
 
 from ..utils import capture_error
 
@@ -51,7 +53,7 @@ def create_and_launch_partition_backfill(graphene_info, backfill_params):
     elif backfill_params.get("partitionNames"):
         partition_names = backfill_params.get("partitionNames")
     else:
-        raise Exception(
+        raise DagsterError(
             'Backfill requested without specifying either "allPartitions" or "partitionNames" '
             "arguments"
         )
@@ -66,6 +68,12 @@ def create_and_launch_partition_backfill(graphene_info, backfill_params):
         reexecution_steps=backfill_params.get("reexecutionSteps"),
         tags={t["key"]: t["value"] for t in backfill_params.get("tags", [])},
         backfill_timestamp=pendulum.now("UTC").timestamp(),
+        asset_selection=[
+            AssetKey.from_graphql_input(asset_key)
+            for asset_key in backfill_params.get("assetSelection")
+        ]
+        if backfill_params.get("assetSelection")
+        else None,
     )
 
     if backfill_params.get("forceSynchronousSubmission"):
