@@ -1,12 +1,12 @@
 import sys
 
-from graphql.execution.base import ResolveInfo
+from graphene import ResolveInfo
 
 import dagster._check as check
-from dagster.config.validate import validate_config_from_snap
-from dagster.core.host_representation import ExternalPipeline, PipelineSelector, RepositorySelector
-from dagster.core.workspace.context import BaseWorkspaceRequestContext
-from dagster.utils.error import serializable_error_info_from_exc_info
+from dagster._config import validate_config_from_snap
+from dagster._core.host_representation import ExternalPipeline, PipelineSelector, RepositorySelector
+from dagster._core.workspace.context import BaseWorkspaceRequestContext
+from dagster._utils.error import serializable_error_info_from_exc_info
 
 from .utils import UserFacingGraphQLError, capture_error
 
@@ -36,8 +36,8 @@ def get_external_pipeline_or_raise(graphene_info, selector):
 
 
 def get_subset_external_pipeline(context, selector):
+    from ..schema.errors import GrapheneInvalidSubsetError
     from ..schema.pipelines.pipeline import GraphenePipeline
-    from ..schema.pipelines.pipeline_errors import GrapheneInvalidSubsetError
 
     check.inst_param(selector, "selector", PipelineSelector)
 
