@@ -1,14 +1,20 @@
-import yaml
-from graphql.execution.base import ResolveInfo
+from graphene import ResolveInfo
 
 import dagster._check as check
-from dagster.core.host_representation import (
+from dagster._core.host_representation import (
     ExternalPartitionSet,
     RepositoryHandle,
     RepositorySelector,
 )
-from dagster.core.storage.pipeline_run import RunsFilter
-from dagster.core.storage.tags import PARTITION_NAME_TAG, PARTITION_SET_TAG, TagType, get_tag_type
+from dagster._core.storage.pipeline_run import RunsFilter
+from dagster._core.storage.tags import (
+    PARTITION_NAME_TAG,
+    PARTITION_SET_TAG,
+    REPOSITORY_LABEL_TAG,
+    TagType,
+    get_tag_type,
+)
+from dagster._utils.yaml_utils import dump_run_config_yaml
 
 from .utils import capture_error
 
@@ -95,9 +101,7 @@ def get_partition_config(graphene_info, repository_handle, partition_set_name, p
         partition_name,
     )
 
-    return GraphenePartitionRunConfig(
-        yaml=yaml.safe_dump(result.run_config, default_flow_style=False)
-    )
+    return GraphenePartitionRunConfig(yaml=dump_run_config_yaml(result.run_config))
 
 
 @capture_error
@@ -174,24 +178,60 @@ def _apply_cursor_limit_reverse(items, cursor, limit, reverse):
 def get_partition_set_partition_statuses(
     graphene_info, repository_handle, partition_set_name, job_name
 ):
-    from ..schema.partition_sets import GraphenePartitionStatus, GraphenePartitionStatuses
-
     check.inst_param(repository_handle, "repository_handle", RepositoryHandle)
     check.str_param(partition_set_name, "partition_set_name")
+    check.str_param(job_name, "job_name")
+
     run_partition_data = graphene_info.context.instance.run_storage.get_run_partition_data(
-        partition_set_name, job_name, repository_handle.get_external_origin().get_id()
+        runs_filter=RunsFilter(
+            pipeline_name=job_name,
+            tags={REPOSITORY_LABEL_TAG: repository_handle.get_external_origin().get_label()},
+        )
     )
-    return GraphenePartitionStatuses(
-        results=[
-            GraphenePartitionStatus(
-                id=f"{partition_set_name}:{p.partition}",
-                partitionName=p.partition,
-                runStatus=p.status,
-                runDuration=p.end_time - p.start_time if p.end_time and p.start_time else None,
+    names_result = graphene_info.context.get_external_partition_names(
+        repository_handle, partition_set_name
+    )
+
+    return partition_statuses_from_run_partition_data(
+        partition_set_name, run_partition_data, names_result.partition_names
+    )
+
+
+def partition_statuses_from_run_partition_data(
+    partition_set_name, run_partition_data, partition_names, backfill_id=None
+):
+    from ..schema.partition_sets import GraphenePartitionStatus, GraphenePartitionStatuses
+
+    partition_data_by_name = {
+        partition_data.partition: partition_data for partition_data in run_partition_data
+    }
+
+    suffix = f":{backfill_id}" if backfill_id else ""
+
+    results = []
+    for name in partition_names:
+        if not partition_data_by_name.get(name):
+            results.append(
+                GraphenePartitionStatus(
+                    id=f"{partition_set_name}:{name}",
+                    partitionName=name,
+                )
             )
-            for p in run_partition_data
-        ]
-    )
+            continue
+        partition_data = partition_data_by_name[name]
+        results.append(
+            GraphenePartitionStatus(
+                id=f"{partition_set_name}:{name}{suffix}",
+                partitionName=name,
+                runId=partition_data.run_id,
+                runStatus=partition_data.status,
+                runDuration=partition_data.end_time - partition_data.start_time
+                if partition_data.end_time and partition_data.start_time
+                else None,
+            )
+        )
+
+    return GraphenePartitionStatuses(results=results)
 
 
 def get_partition_set_partition_runs(graphene_info, partition_set):
