@@ -1,7 +1,7 @@
-from graphql.execution.base import ResolveInfo
+from graphene import ResolveInfo
 
 import dagster._check as check
-from dagster.core.storage.pipeline_run import PipelineRun
+from dagster._core.storage.pipeline_run import PipelineRun
 
 from .external import get_external_pipeline_or_raise, get_full_external_pipeline_or_raise
 from .utils import PipelineSelector, UserFacingGraphQLError, capture_error
