@@ -1,10 +1,11 @@
 import graphene
 
 import dagster._check as check
-from dagster.core.execution.backfill import BulkActionStatus, PartitionBackfill
-from dagster.core.storage.pipeline_run import PipelineRunStatus, RunsFilter
-from dagster.core.storage.tags import PARTITION_NAME_TAG
+from dagster._core.execution.backfill import BulkActionStatus, PartitionBackfill
+from dagster._core.storage.pipeline_run import FINISHED_STATUSES, PipelineRunStatus, RunsFilter
+from dagster._core.storage.tags import BACKFILL_ID_TAG
 
+from ..implementation.fetch_partition_sets import partition_statuses_from_run_partition_data
 from .errors import (
     GrapheneInvalidOutputError,
     GrapheneInvalidStepError,
@@ -96,18 +97,6 @@ class GrapheneBackfillStatus(graphene.Enum):
         name = "BackfillStatus"
 
 
-class GrapheneBackfillRunStats(graphene.ObjectType):
-    class Meta:
-        name = "BackfillRunStats"
-
-    numQueued = graphene.NonNull(graphene.Int)
-    numInProgress = graphene.NonNull(graphene.Int)
-    numSucceeded = graphene.NonNull(graphene.Int)
-    numFailed = graphene.NonNull(graphene.Int)
-    numPartitionsWithRuns = graphene.NonNull(graphene.Int)
-    numTotalRuns = graphene.NonNull(graphene.Int)
-
-
 class GraphenePartitionBackfill(graphene.ObjectType):
     class Meta:
         name = "PartitionBackfill"
@@ -132,12 +121,15 @@ class GraphenePartitionBackfill(graphene.ObjectType):
         limit=graphene.Int(),
     )
     error = graphene.Field(GraphenePythonError)
-    partitionRunStats = graphene.NonNull(GrapheneBackfillRunStats)
+    partitionStatuses = graphene.NonNull(
+        "dagster_graphql.schema.partition_sets.GraphenePartitionStatuses"
+    )
 
     def __init__(self, backfill_job):
         self._backfill_job = check.opt_inst_param(backfill_job, "backfill_job", PartitionBackfill)
 
         self._records = None
+        self._partition_run_data = None
 
         super().__init__(
             backfillId=backfill_job.backfill_id,
@@ -149,110 +141,7 @@ class GraphenePartitionBackfill(graphene.ObjectType):
             timestamp=backfill_job.backfill_timestamp,
         )
 
-    def _get_records(self, graphene_info):
-        if self._records == None:
-            filters = RunsFilter.for_backfill(self._backfill_job.backfill_id)
-            self._records = graphene_info.context.instance.get_run_records(
-                filters=filters,
-            )
-        return self._records
-
-    def resolve_unfinishedRuns(self, graphene_info):
-        from .pipelines.pipeline import GrapheneRun
-
-        records = self._get_records(graphene_info)
-        return [GrapheneRun(record) for record in records if not record.pipeline_run.is_finished]
-
-    def resolve_backfillStatus(self, graphene_info):
-        if self._backfill_job.status == BulkActionStatus.REQUESTED:
-            return GrapheneBackfillStatus.REQUESTED
-        if self._backfill_job.status == BulkActionStatus.CANCELED:
-            return GrapheneBackfillStatus.CANCELED
-        if self._backfill_job.status == BulkActionStatus.FAILED:
-            return GrapheneBackfillStatus.FAILED
-        if self._backfill_job.status == BulkActionStatus.COMPLETED:
-            records = self._get_records(graphene_info)
-
-            is_done = all(record.pipeline_run.is_finished for record in records)
-            if not is_done:
-                return GrapheneBackfillStatus.IN_PROGRESS
-            else:
-                num_success = len(
-                    [
-                        record
-                        for record in records
-                        if record.pipeline_run.status == PipelineRunStatus.SUCCESS
-                    ]
-                )
-                if num_success == len(self._backfill_job.partition_names):
-                    return GrapheneBackfillStatus.COMPLETED
-                else:
-                    return GrapheneBackfillStatus.INCOMPLETE
-
-    def resolve_partitionRunStats(self, graphene_info):
-        records = self._get_records(graphene_info)
-
-        by_partition_records = {}
-
-        for record in records:
-            partition = record.pipeline_run.tags.get(PARTITION_NAME_TAG)
-            if partition and partition not in by_partition_records:  # get latest for each partition
-                by_partition_records[partition] = record
-
-        num_queued = 0
-        num_in_progress = 0
-        num_succeeded = 0
-        num_failed = 0
-
-        for _partition, record in by_partition_records.items():
-            status = record.pipeline_run.status
-            if status == PipelineRunStatus.QUEUED:
-                num_queued = num_queued + 1
-            elif not record.pipeline_run.is_finished:
-                num_in_progress = num_in_progress + 1
-            elif status == PipelineRunStatus.SUCCESS:
-                num_succeeded = num_succeeded + 1
-            elif status in {PipelineRunStatus.FAILURE, PipelineRunStatus.CANCELED}:
-                num_failed = num_failed + 1
-            else:
-                check.invariant(False, f"Unexpected PipelineRunStatus {status}")
-
-        return GrapheneBackfillRunStats(
-            numQueued=num_queued,
-            numInProgress=num_in_progress,
-            numSucceeded=num_succeeded,
-            numFailed=num_failed,
-            numPartitionsWithRuns=len(by_partition_records),
-            numTotalRuns=len(records),
-        )
-
-    def resolve_runs(self, graphene_info):
-        from .pipelines.pipeline import GrapheneRun
-
-        records = self._get_records(graphene_info)
-        return [GrapheneRun(record) for record in records]
-
-    def resolve_numPartitions(self, _graphene_info):
-        return len(self._backfill_job.partition_names)
-
-    def resolve_numRequested(self, graphene_info):
-        if self._backfill_job.status == BulkActionStatus.COMPLETED:
-            return len(self._backfill_job.partition_names)
-
-        records = self._get_records(graphene_info)
-
-        run_count = len(records)
-        checkpoint = self._backfill_job.last_submitted_partition_name
-        return max(
-            run_count,
-            self._backfill_job.partition_names.index(checkpoint) + 1
-            if checkpoint and checkpoint in self._backfill_job.partition_names
-            else 0,
-        )
-
-    def resolve_partitionSet(self, graphene_info):
-        from ..schema.partition_sets import GraphenePartitionSet
-
+    def _get_partition_set(self, graphene_info):
         origin = self._backfill_job.partition_set_origin
         location_name = origin.external_repository_origin.repository_location_origin.location_name
         repository_name = origin.external_repository_origin.repository_name
@@ -272,12 +161,106 @@ class GraphenePartitionBackfill(graphene.ObjectType):
         if not external_partition_sets:
             return None
 
-        partition_set = external_partition_sets[0]
+        return external_partition_sets[0]
+
+    def _get_records(self, graphene_info):
+        if self._records == None:
+            filters = RunsFilter.for_backfill(self._backfill_job.backfill_id)
+            self._records = graphene_info.context.instance.get_run_records(
+                filters=filters,
+            )
+        return self._records
+
+    def _get_partition_run_data(self, graphene_info):
+        if self._partition_run_data is None:
+            self._partition_run_data = (
+                graphene_info.context.instance.run_storage.get_run_partition_data(
+                    runs_filter=RunsFilter(
+                        tags={
+                            BACKFILL_ID_TAG: self._backfill_job.backfill_id,
+                        }
+                    )
+                )
+            )
+        return self._partition_run_data
+
+    def resolve_unfinishedRuns(self, graphene_info):
+        from .pipelines.pipeline import GrapheneRun
+
+        records = self._get_records(graphene_info)
+        return [GrapheneRun(record) for record in records if not record.pipeline_run.is_finished]
+
+    def resolve_backfillStatus(self, graphene_info):
+        if self._backfill_job.status == BulkActionStatus.REQUESTED:
+            return GrapheneBackfillStatus.REQUESTED
+        if self._backfill_job.status == BulkActionStatus.CANCELED:
+            return GrapheneBackfillStatus.CANCELED
+        if self._backfill_job.status == BulkActionStatus.FAILED:
+            return GrapheneBackfillStatus.FAILED
+        if self._backfill_job.status == BulkActionStatus.COMPLETED:
+            partition_run_data = self._get_partition_run_data(graphene_info)
+            is_done = all(partition.status in FINISHED_STATUSES for partition in partition_run_data)
+            if not is_done:
+                return GrapheneBackfillStatus.IN_PROGRESS
+            else:
+                num_success = len(
+                    [
+                        partition
+                        for partition in partition_run_data
+                        if partition.status == PipelineRunStatus.SUCCESS
+                    ]
+                )
+                if num_success == len(self._backfill_job.partition_names):
+                    return GrapheneBackfillStatus.COMPLETED
+                else:
+                    return GrapheneBackfillStatus.INCOMPLETE
+
+    def resolve_runs(self, graphene_info):
+        from .pipelines.pipeline import GrapheneRun
+
+        records = self._get_records(graphene_info)
+        return [GrapheneRun(record) for record in records]
+
+    def resolve_numPartitions(self, _graphene_info):
+        return len(self._backfill_job.partition_names)
+
+    def resolve_numRequested(self, graphene_info):
+        if self._backfill_job.status == BulkActionStatus.COMPLETED:
+            return len(self._backfill_job.partition_names)
+
+        partition_run_data = self._get_partition_run_data(graphene_info)
+
+        checkpoint = self._backfill_job.last_submitted_partition_name
+        return max(
+            len(partition_run_data),
+            self._backfill_job.partition_names.index(checkpoint) + 1
+            if checkpoint and checkpoint in self._backfill_job.partition_names
+            else 0,
+        )
+
+    def resolve_partitionSet(self, graphene_info):
+        from ..schema.partition_sets import GraphenePartitionSet
+
+        partition_set = self._get_partition_set(graphene_info)
+
+        if not partition_set:
+            return None
+
         return GraphenePartitionSet(
-            external_repository_handle=repository.handle,
+            external_repository_handle=partition_set.repository_handle,
             external_partition_set=partition_set,
         )
 
+    def resolve_partitionStatuses(self, graphene_info):
+        partition_set_name = self._backfill_job.partition_set_origin.partition_set_name
+        partition_run_data = self._get_partition_run_data(graphene_info)
+        return partition_statuses_from_run_partition_data(
+            partition_set_name,
+            partition_run_data,
+            self._backfill_job.partition_names,
+            backfill_id=self._backfill_job.backfill_id,
+        )
+
     def resolve_error(self, _):
         if self._backfill_job.error:
             return GraphenePythonError(self._backfill_job.error)
