@@ -4,8 +4,13 @@ import graphene
 from graphene.types.generic import GenericScalar
 
 import dagster._check as check
-from dagster.config.errors import EvaluationError as DagsterEvaluationError
-from dagster.config.errors import (
+from dagster._config import ConfigSchemaSnapshot
+from dagster._config import EvaluationError as DagsterEvaluationError
+from dagster._config import (
+    EvaluationStackListItemEntry,
+    EvaluationStackMapKeyEntry,
+    EvaluationStackMapValueEntry,
+    EvaluationStackPathEntry,
     FieldNotDefinedErrorData,
     FieldsNotDefinedErrorData,
     MissingFieldErrorData,
@@ -13,15 +18,8 @@ from dagster.config.errors import (
     RuntimeMismatchErrorData,
     SelectorTypeErrorData,
 )
-from dagster.config.snap import ConfigSchemaSnapshot
-from dagster.config.stack import (
-    EvaluationStackListItemEntry,
-    EvaluationStackMapKeyEntry,
-    EvaluationStackMapValueEntry,
-    EvaluationStackPathEntry,
-)
-from dagster.core.host_representation.represented import RepresentedPipeline
-from dagster.utils.error import SerializableErrorInfo
+from dagster._core.host_representation.represented import RepresentedPipeline
+from dagster._utils.error import SerializableErrorInfo
 
 from ..config_types import GrapheneConfigTypeField
 from ..util import non_null_list
