@@ -1,9 +1,7 @@
-# pylint: disable=missing-graphene-docstring
 import graphene
 
-from ..errors import GraphenePipelineNotFoundError, GraphenePythonError
+from ..errors import GrapheneInvalidSubsetError, GraphenePipelineNotFoundError, GraphenePythonError
 from .config import GraphenePipelineConfigValidationValid, GrapheneRunConfigValidationInvalid
-from .pipeline_errors import GrapheneInvalidSubsetError
 
 
 class GraphenePipelineConfigValidationResult(graphene.Union):
